==> javascriptstuff-db-1.10.2.tgz: package/state-managers.js <==
module.exports = {
  "key": "state-managers",
  "name": "State Managers",
  "description": "These manage the state of your JavaScript application.",
  "aka": [
    "flux libraries"
  ],
  "tags": [
    {
      "name": "pure flux",
      "description": "Matches exactly the original definition of flux"
    },
    {
      "name": "react",
      "description": "Has code or documentation that specifically helps to integrate with React"
    },
    {
      "name": "redux",
      "description": "A Redux plugin"
    },
    {
      "name": "mobx",
      "description": "A MobX plugin."
    },
    {
      "name": "vue"
    }
  ],
  "articles": [],
  "projects": [
    {
      "githubPath": "cerebral/cerebral",
      "description": "Declarative state and side effects management for popular JavaScript frameworks",
      "homepage": "http://cerebraljs.com",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 1430,
      "lastUpdatedAt": "2018-02-14T21:31:36Z",
      "avatarUrl": "https://avatars1.githubusercontent.com/u/15994611?v=4"
    },
    {
      "githubPath": "jumpsuit/jumpstate",
      "description": "Jumpstate is a simple and powerful state management utility for Redux.",
      "homepage": "",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 363,
      "lastUpdatedAt": "2018-02-14T21:30:12Z",
      "avatarUrl": "https://avatars2.githubusercontent.com/u/15242149?v=4"
    },
    {
      "githubPath": "dvajs/dva",
      "description": "🌱 React and redux based, lightweight and elm-style framework. (Inspired by elm and choo)",
      "homepage": "",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 8030,
      "lastUpdatedAt": "2018-02-15T15:40:03Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/20552239?v=4"
    },
    {
      "githubPath": "keajs/kea",
      "description": "High level abstraction between React and Redux",
      "homepage": "https://kea.js.org/",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 1227,
      "lastUpdatedAt": "2018-02-14T21:21:06Z",
      "avatarUrl": "https://avatars2.githubusercontent.com/u/30091805?v=4"
    },
    {
      "githubPath": "Olical/EventEmitter",
      "description": "Evented JavaScript for the browser",
      "homepage": "",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 2305,
      "lastUpdatedAt": "2018-02-13T07:49:51Z",
      "avatarUrl": "https://avatars0.githubusercontent.com/u/315229?v=4"
    },
    {
      "githubPath": "jeromeetienne/microevent.js",
      "description": "event emitter microlibrary - 20lines -for node and browser",
      "homepage": "http://notes.jetienne.com/2011/03/22/microeventjs.html",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 742,
      "lastUpdatedAt": "2018-02-15T14:03:58Z",
      "avatarUrl": "https://avatars2.githubusercontent.com/u/252962?v=4"
    },
    {
      "githubPath": "mroderick/PubSubJS",
      "description": "Dependency free publish/subscribe for JavaScript",
      "homepage": "",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 2198,
      "lastUpdatedAt": "2018-02-15T08:10:12Z",
      "avatarUrl": "https://avatars2.githubusercontent.com/u/20321?v=4"
    },
    {
      "githubPath": "solkimicreb/react-easy-state",
      "description": "Simple React state management. Made with ❤️ and ES6 Proxies.",
      "homepage": "",
      "dependencies": null,
      "tags": [
        "react"
      ],
      "lastStarCount": 643,
      "lastUpdatedAt": "2018-02-15T15:48:37Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/6956014?v=4"
    },
    {
      "githubPath": "facebook/flux",
      "description": "Application Architecture for Building User Interfaces",
      "homepage": "http://facebook.github.io/flux/",
      "dependencies": null,
      "tags": [
        "pure flux"
      ],
      "lastStarCount": 14846,
      "lastUpdatedAt": "2018-02-15T15:17:17Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/69631?v=4"
    },
    {
      "githubPath": "goatslacker/alt",
      "description": "Isomorphic flux implementation",
      "homepage": "http://alt.js.org/",
      "dependencies": null,
      "tags": [
        "pure flux"
      ],
      "lastStarCount": 3453,
      "lastUpdatedAt": "2018-02-14T07:43:12Z",
      "avatarUrl": "https://avatars1.githubusercontent.com/u/10632?v=4"
    },
    {
      "githubPath": "optimizely/nuclear-js",
      "description": "Reactive Flux built with ImmutableJS data structures. Framework agnostic.",
      "homepage": "https://optimizely.github.io/nuclear-js/",
      "dependencies": null,
      "tags": [
        "pure flux"
      ],
      "lastStarCount": 1845,
      "lastUpdatedAt": "2018-02-13T21:49:07Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/1274132?v=4"
    },
    {
      "githubPath": "yahoo/fluxible",
      "description": "A pluggable container for universal flux applications",
      "homepage": "http://fluxible.io",
      "dependencies": null,
      "tags": [
        "pure flux"
      ],
      "lastStarCount": 1784,
      "lastUpdatedAt": "2018-02-05T05:10:55Z",
      "avatarUrl": "https://avatars1.githubusercontent.com/u/16574?v=4"
    },
    {
      "githubPath": "acdlite/flummox",
      "description": "Minimal, isomorphic Flux.",
      "homepage": "http://acdlite.github.io/flummox",
      "dependencies": null,
      "tags": [
        "pure flux"
      ],
      "lastStarCount": 1660,
      "lastUpdatedAt": "2018-02-14T07:40:52Z",
      "avatarUrl": "https://avatars0.githubusercontent.com/u/3624098?v=4"
    },
    {
      "githubPath": "mobxjs/mobx",
      "description": "Simple, scalable state management.",
      "homepage": "http://mobx.js.org",
      "dependencies": null,
      "tags": [
        "react",
        "mobx"
      ],
      "lastStarCount": 13347,
      "lastUpdatedAt": "2018-02-15T15:20:01Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/17475736?v=4"
    },
    {
      "githubPath": "mobxjs/mobx-state-tree",
      "description": "Opinionated, transactional, MobX powered state container",
      "homepage": "",
      "dependencies": null,
      "tags": [
        "react",
        "mobx"
      ],
      "lastStarCount": 2142,
      "lastUpdatedAt": "2018-02-15T16:12:03Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/17475736?v=4"
    },
    {
      "githubPath": "reactjs/redux",
      "description": "Predictable state container for JavaScript apps",
      "homepage": "http://redux.js.org",
      "dependencies": null,
      "tags": [
        "react",
        "redux"
      ],
      "lastStarCount": 38181,
      "lastUpdatedAt": "2018-02-15T16:18:02Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/6412038?v=4"
    },
    {
      "githubPath": "redux-saga/redux-saga",
      "description": "An alternative side effect model for Redux apps",
      "homepage": "https://redux-saga.js.org/",
      "dependencies": null,
      "tags": [
        "react",
        "redux"
      ],
      "lastStarCount": 11969,
      "lastUpdatedAt": "2018-02-15T16:35:59Z",
      "avatarUrl": "https://avatars2.githubusercontent.com/u/24776643?v=4"
    },
    {
      "githubPath": "reactjs/react-redux",
      "description": "Official React bindings for Redux",
      "homepage": "http://redux.js.org/docs/basics/UsageWithReact.html",
      "dependencies": null,
      "tags": [
        "react",
        "redux"
      ],
      "lastStarCount": 11237,
      "lastUpdatedAt": "2018-02-15T13:07:43Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/6412038?v=4"
    },
    {
      "githubPath": "tommikaikkonen/redux-orm",
      "description": "A small, simple and immutable ORM to manage relational data in your Redux store.",
      "homepage": "",
      "dependencies": null,
      "tags": [
        "react",
        "redux"
      ],
      "lastStarCount": 1778,
      "lastUpdatedAt": "2018-02-15T15:24:18Z",
      "avatarUrl": "https://avatars2.githubusercontent.com/u/2487359?v=4"
    },
    {
      "githubPath": "vuejs/vuex",
      "description": "🗃️ Centralized State Management for Vue.js.",
      "homepage": "https://vuex.vuejs.org",
      "dependencies": null,
      "tags": [
        "vue"
      ],
      "lastStarCount": 12794,
      "lastUpdatedAt": "2018-02-15T16:36:27Z",
      "avatarUrl": "https://avatars1.githubusercontent.com/u/6128107?v=4"
    },
    {
      "githubPath": "cerebral/cerebral",
      "description": "Declarative state and side effects management for popular JavaScript frameworks",
      "homepage": "http://cerebraljs.com",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 1430,
      "lastUpdatedAt": "2018-02-14T21:31:36Z",
      "avatarUrl": "https://avatars1.githubusercontent.com/u/15994611?v=4"
    },
    {
      "githubPath": "robinvdvleuten/vuex-persistedstate",
      "description": "💾 Persist Vuex state with localStorage.",
      "homepage": "http://npm.im/vuex-persistedstate",
      "dependencies": null,
      "tags": [
        "vue"
      ],
      "lastStarCount": 1132,
      "lastUpdatedAt": "2018-02-15T16:23:01Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/238295?v=4"
    },
    {
      "githubPath": "moreartyjs/moreartyjs",
      "description": "Morearty.js - centralized state management for React in pure JavaScript",
      "homepage": "",
      "dependencies": null,
      "tags": [
        "react"
      ],
      "lastStarCount": 669,
      "lastUpdatedAt": "2018-02-11T16:25:00Z",
      "avatarUrl": "https://avatars2.githubusercontent.com/u/9162275?v=4"
    }
  ]
}

==> javascriptstuff-db-1.11.0.tgz: package/state-managers.js <==
module.exports = {
  "key": "state-managers",
  "name": "State Managers",
  "description": "These manage the state of your JavaScript application.",
  "aka": [
    "flux libraries"
  ],
  "tags": [
    {
      "name": "pure flux",
      "description": "Matches exactly the original definition of flux"
    },
    {
      "name": "react",
      "description": "Has code or documentation that specifically helps to integrate with React"
    },
    {
      "name": "redux",
      "description": "A Redux plugin"
    },
    {
      "name": "mobx",
      "description": "A MobX plugin."
    },
    {
      "name": "vue"
    }
  ],
  "articles": [],
  "projects": [
    {
      "githubPath": "bcherny/undux",
      "description": "⚡️ Dead simple state management for React",
      "homepage": "",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 604,
      "lastUpdatedAt": "2018-04-13T17:50:42Z",
      "avatarUrl": "https://avatars2.githubusercontent.com/u/1761758?v=4"
    },
    {
      "githubPath": "mweststrate/immer",
      "description": "Create the next immutable state by mutating the current one",
      "homepage": "",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 4046,
      "lastUpdatedAt": "2018-04-13T20:01:26Z",
      "avatarUrl": "https://avatars0.githubusercontent.com/u/1820292?v=4"
    },
    {
      "githubPath": "cerebral/cerebral",
      "description": "Declarative state and side effects management for popular JavaScript frameworks",
      "homepage": "http://cerebraljs.com",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 1511,
      "lastUpdatedAt": "2018-04-13T19:04:11Z",
      "avatarUrl": "https://avatars1.githubusercontent.com/u/15994611?v=4"
    },
    {
      "githubPath": "jumpsuit/jumpstate",
      "description": "Jumpstate is a simple and powerful state management utility for Redux.",
      "homepage": "",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 379,
      "lastUpdatedAt": "2018-04-12T05:51:27Z",
      "avatarUrl": "https://avatars2.githubusercontent.com/u/15242149?v=4"
    },
    {
      "githubPath": "dvajs/dva",
      "description": "🌱 React and redux based, lightweight and elm-style framework. (Inspired by elm and choo)",
      "homepage": "",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 8914,
      "lastUpdatedAt": "2018-04-13T14:06:06Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/20552239?v=4"
    },
    {
      "githubPath": "keajs/kea",
      "description": "High level abstraction between React and Redux",
      "homepage": "https://kea.js.org/",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 1288,
      "lastUpdatedAt": "2018-04-12T12:23:41Z",
      "avatarUrl": "https://avatars2.githubusercontent.com/u/30091805?v=4"
    },
    {
      "githubPath": "Olical/EventEmitter",
      "description": "Evented JavaScript for the browser",
      "homepage": "",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 2377,
      "lastUpdatedAt": "2018-04-12T14:50:40Z",
      "avatarUrl": "https://avatars0.githubusercontent.com/u/315229?v=4"
    },
    {
      "githubPath": "jeromeetienne/microevent.js",
      "description": "event emitter microlibrary - 20lines -for node and browser",
      "homepage": "http://notes.jetienne.com/2011/03/22/microeventjs.html",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 744,
      "lastUpdatedAt": "2018-04-10T17:13:57Z",
      "avatarUrl": "https://avatars2.githubusercontent.com/u/252962?v=4"
    },
    {
      "githubPath": "mroderick/PubSubJS",
      "description": "Dependency free publish/subscribe for JavaScript",
      "homepage": "",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 2273,
      "lastUpdatedAt": "2018-04-11T10:46:52Z",
      "avatarUrl": "https://avatars2.githubusercontent.com/u/20321?v=4"
    },
    {
      "githubPath": "solkimicreb/react-easy-state",
      "description": "Simple React state management. Made with ❤️ and ES6 Proxies.",
      "homepage": "",
      "dependencies": null,
      "tags": [
        "react"
      ],
      "lastStarCount": 877,
      "lastUpdatedAt": "2018-04-10T22:21:01Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/6956014?v=4"
    },
    {
      "githubPath": "facebook/flux",
      "description": "Application Architecture for Building User Interfaces",
      "homepage": "http://facebook.github.io/flux/",
      "dependencies": null,
      "tags": [
        "pure flux"
      ],
      "lastStarCount": 15047,
      "lastUpdatedAt": "2018-04-13T18:52:49Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/69631?v=4"
    },
    {
      "githubPath": "goatslacker/alt",
      "description": "Isomorphic flux implementation",
      "homepage": "http://alt.js.org/",
      "dependencies": null,
      "tags": [
        "pure flux"
      ],
      "lastStarCount": 3472,
      "lastUpdatedAt": "2018-04-13T01:42:33Z",
      "avatarUrl": "https://avatars1.githubusercontent.com/u/10632?v=4"
    },
    {
      "githubPath": "optimizely/nuclear-js",
      "description": "Reactive Flux built with ImmutableJS data structures. Framework agnostic.",
      "homepage": "https://optimizely.github.io/nuclear-js/",
      "dependencies": null,
      "tags": [
        "pure flux"
      ],
      "lastStarCount": 1863,
      "lastUpdatedAt": "2018-04-13T07:34:31Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/1274132?v=4"
    },
    {
      "githubPath": "yahoo/fluxible",
      "description": "A pluggable container for universal flux applications",
      "homepage": "http://fluxible.io",
      "dependencies": null,
      "tags": [
        "pure flux"
      ],
      "lastStarCount": 1797,
      "lastUpdatedAt": "2018-04-11T13:28:10Z",
      "avatarUrl": "https://avatars1.githubusercontent.com/u/16574?v=4"
    },
    {
      "githubPath": "acdlite/flummox",
      "description": "Minimal, isomorphic Flux.",
      "homepage": "http://acdlite.github.io/flummox",
      "dependencies": null,
      "tags": [
        "pure flux"
      ],
      "lastStarCount": 1681,
      "lastUpdatedAt": "2018-04-13T07:34:13Z",
      "avatarUrl": "https://avatars0.githubusercontent.com/u/3624098?v=4"
    },
    {
      "githubPath": "mobxjs/mobx",
      "description": "Simple, scalable state management.",
      "homepage": "http://mobx.js.org",
      "dependencies": null,
      "tags": [
        "react",
        "mobx"
      ],
      "lastStarCount": 14451,
      "lastUpdatedAt": "2018-04-13T18:41:09Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/17475736?v=4"
    },
    {
      "githubPath": "mobxjs/mobx-state-tree",
      "description": "Model Driven State Management",
      "homepage": "",
      "dependencies": null,
      "tags": [
        "react",
        "mobx"
      ],
      "lastStarCount": 2453,
      "lastUpdatedAt": "2018-04-13T15:49:11Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/17475736?v=4"
    },
    {
      "githubPath": "reactjs/redux",
      "description": "Predictable state container for JavaScript apps",
      "homepage": "http://redux.js.org",
      "dependencies": null,
      "tags": [
        "react",
        "redux"
      ],
      "lastStarCount": 39920,
      "lastUpdatedAt": "2018-04-13T20:00:30Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/6412038?v=4"
    },
    {
      "githubPath": "redux-saga/redux-saga",
      "description": "An alternative side effect model for Redux apps",
      "homepage": "https://redux-saga.js.org/",
      "dependencies": null,
      "tags": [
        "react",
        "redux"
      ],
      "lastStarCount": 12807,
      "lastUpdatedAt": "2018-04-13T19:42:33Z",
      "avatarUrl": "https://avatars2.githubusercontent.com/u/24776643?v=4"
    },
    {
      "githubPath": "reactjs/react-redux",
      "description": "Official React bindings for Redux",
      "homepage": "https://redux.js.org/basics/usage-with-react",
      "dependencies": null,
      "tags": [
        "react",
        "redux"
      ],
      "lastStarCount": 12056,
      "lastUpdatedAt": "2018-04-13T19:06:12Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/6412038?v=4"
    },
    {
      "githubPath": "tommikaikkonen/redux-orm",
      "description": "A small, simple and immutable ORM to manage relational data in your Redux store.",
      "homepage": "",
      "dependencies": null,
      "tags": [
        "react",
        "redux"
      ],
      "lastStarCount": 1883,
      "lastUpdatedAt": "2018-04-13T17:37:01Z",
      "avatarUrl": "https://avatars2.githubusercontent.com/u/2487359?v=4"
    },
    {
      "githubPath": "vuejs/vuex",
      "description": "🗃️ Centralized State Management for Vue.js.",
      "homepage": "https://vuex.vuejs.org",
      "dependencies": null,
      "tags": [
        "vue"
      ],
      "lastStarCount": 13869,
      "lastUpdatedAt": "2018-04-13T15:23:42Z",
      "avatarUrl": "https://avatars1.githubusercontent.com/u/6128107?v=4"
    },
    {
      "githubPath": "cerebral/cerebral",
      "description": "Declarative state and side effects management for popular JavaScript frameworks",
      "homepage": "http://cerebraljs.com",
      "dependencies": null,
      "tags": [],
      "lastStarCount": 1511,
      "lastUpdatedAt": "2018-04-13T19:04:11Z",
      "avatarUrl": "https://avatars1.githubusercontent.com/u/15994611?v=4"
    },
    {
      "githubPath": "robinvdvleuten/vuex-persistedstate",
      "description": "💾 Persist Vuex state with localStorage.",
      "homepage": "http://npm.im/vuex-persistedstate",
      "dependencies": null,
      "tags": [
        "vue"
      ],
      "lastStarCount": 1374,
      "lastUpdatedAt": "2018-04-13T09:23:19Z",
      "avatarUrl": "https://avatars3.githubusercontent.com/u/238295?v=4"
    },
    {
      "githubPath": "moreartyjs/moreartyjs",
      "description": "Morearty.js - centralized state management for React in pure JavaScript",
      "homepage": "",
      "dependencies": null,
      "tags": [
        "react"
      ],
      "lastStarCount": 670,
      "lastUpdatedAt": "2018-04-13T00:49:26Z",
      "avatarUrl": "https://avatars2.githubusercontent.com/u/9162275?v=4"
    },
    {
      "githubPath": "jamiebuilds/unstated",
      "description": "State so simple, it goes without saying",
      "homepage": "https://unstated.io",
      "dependencies": null,
      "tags": [
        "react"
      ],
      "lastStarCount": 3158,
      "lastUpdatedAt": "2018-04-13T19:42:29Z",
      "avatarUrl": "https://avatars0.githubusercontent.com/u/952783?v=4"
    }
  ]
}
